sandman API
===============

:mod:`exception` Module
-----------------------

.. automodule:: sandman.exception
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`model` Module
-------------------

.. automodule:: sandman.model
    :members: register, activate

.. automodule:: sandman.model.models
    :members:
    :private-members:
    :special-members: __endpoint__, __methods__, __table__, __tablename__
    :undoc-members:
    :show-inheritance:

:mod:`sandman` Module
---------------------

.. automodule:: sandman.sandman
    :members:
    :undoc-members:
    :show-inheritance:
